*  Directory for SAS code, data and output - remember trailing slash;

%let SAMPDIR=C:\HOW\DelGobbo\;

*  Library containing the sample data;

libname sample "&SAMPDIR" access=read;

*  Library to store styles and tagsets;

libname mylib "&SAMPDIR";

*  Set the ODS search path for styles and tagsets;

ods path mylib.tmplmst(update)
         sashelp.tmplmst(read);

*  Include recent version of the ExcelXP ODS tagset;

%include "&SAMPDIR.ExcelXP.sas";

*  Create some formats for our data;

proc format;
  value segment 1 = 'Annual Geographic Segments'
                2 = 'Annual Business Segments'
                3 = 'Quarterly Business Segments';

  value category 1 = 'External Revenue'
                 2 = 'Total Revenue'
                 3 = 'Long-Lived Assets'
                 4 = 'Depreciation'
                 5 = 'Operating Income/Loss';

  value $source 'US' = 'United States'
                'JP' = 'Japan'
                'EU' = 'Europe, Middle East and Africa'
                'OT' = 'Other'
                'PH' = 'Pharmaceutical Division'
                'AO' = 'All Other';
run;  quit;

*  Create a custom style based on the stock "sansPrinter" style;

proc template;

    define style styles.XLsansPrinter;
      parent = styles.sansPrinter;

      /* Controls the appearance of the ID "header" cell */

      style header_id from header /
        font_weight = light;

      /* Assign an Excel format - used with "data" cells */

      style data_comma_1 from data /
        tagattr = 'format:#,###.0';

      /* Assign an Excel format - used with "total" and "grand total" cells */

      style header_comma_1 from header /
        tagattr = 'format:#,###.0';

    end;
run; quit;

ods listing close;

ods tagsets.ExcelXP path="&SAMPDIR" file='PharmaFinancial.xml' style=XLsansprinter;

  *  Use the value of the BY group Category for the title;

  title '#BYVAL(Category)';
  footnote;

  *  Set global options;

  ods tagsets.ExcelXP options(embedded_titles='yes' suppress_bylines='yes'
                              auto_subtotals='yes');

  *  Create a separate worksheet for each business segment;

  ods tagsets.ExcelXP options(sheet_interval='none'
                              sheet_name='Annual Geographic Segments');

  proc print data=mylib.PharmaFinancial noobs label split='*';
    where segment eq 1;  * Annual Geographic Segments;
    by category;
    pageby category;     * Force a new title for each value of Category;
    id source / style(header)=header_id;
    var val2004-val2002 / style(data)=data_comma_1;
    sum val2002-val2004 / style(total)=header_comma_1  style(grandtotal)=header_comma_1;
    label source = 'Millions of USD';
  run; quit;

  ods tagsets.ExcelXP options(sheet_interval='none'
                              sheet_name='Annual Business Segments');

  proc print data=mylib.PharmaFinancial noobs label split='*';
    where segment eq 2;  * Annual Business Segments;
    by category;
    pageby category;     * Force a new title for each value of Category;
    id source / style(header)=header_id;
    var val2004-val2002 / style(data)=data_comma_1;
    sum val2002-val2004 / style(total)=header_comma_1  style(grandtotal)=header_comma_1;
    label source = 'Millions of USD';
  run; quit;

  ods tagsets.ExcelXP options(sheet_interval='none'
                              sheet_name='Quarterly Business Segments');

  proc print data=mylib.PharmaFinancial noobs label split='*';
    where segment eq 3;  * Quarterly Business Segments;
    by category;
    pageby category;     * Force a new title for each value of Category;
    id source / style(header)=header_id;
    var val2004-val2002 / style(data)=data_comma_1;
    sum val2002-val2004 / style(total)=header_comma_1  style(grandtotal)=header_comma_1;
    label source = 'Millions of USD';
  run; quit;

ods tagsets.ExcelXP close;