*;
*  Change appearance with Excel formats (via ODS style overrides);
*;

*  NOTE: Make sure you have already run Setup.sas to set up the environment;

*  Create a custom style based on the stock "sansPrinter" style;

proc template;

    define style styles.XLsansPrinter;
      parent = styles.sansPrinter;

      /* Controls the appearance of the ID "header" cell */

      style header_id from header /
        font_weight = light
        font_style  = italic   /* New */
        just        = center;  /* New */
        
      /* Assign Excel formats - used with "data" cells */

      style data_comma_1 from data /
        tagattr = 'format:#,###.0';

      style data_currency from data /
        tagattr = 'format:Currency';  /* New */

      style data_comma from data /
        tagattr = 'format:#,###';  /* New */

      /* Assign Excel formats - used with "total" and "grand total" cells */

      style header_comma_1 from header /
        tagattr     = 'format:#,###.0'
        background  = #ccccff;  /* New */

      style header_currency from header /  /* New */
        tagattr     = 'format:Currency'  
        background  = #ccccff;

      style header_comma from header /  /* New */
        tagattr     = 'format:#,###'  
        background  = #ccccff;

    end;
run; quit;


ods listing close;

ods tagsets.ExcelXP path="&SAMPDIR" file='PharmaFinancial.xml' style=XLsansprinter;

  *  Use the value of the BY group Category for the title;

  title '#BYVAL(Category)';
  footnote;

  *  Set global options;

  ods tagsets.ExcelXP options(embedded_titles='yes' suppress_bylines='yes'
                              auto_subtotals='yes');

  *  Create a separate worksheet for each business segment;

  ods tagsets.ExcelXP options(sheet_interval='none'
                              sheet_name='Annual Geographic Segments');

  proc print data=mylib.PharmaFinancial noobs label split='*';
    where segment eq 1;  * Annual Geographic Segments;
    by category;
    pageby category;     * Force a new title for each value of Category;
    id source / style(header)=header_id;
    var val2004-val2002 / style(data)=data_comma_1;
    sum val2002-val2004 / style(total)=header_comma_1  style(grandtotal)=header_comma_1;
    label source = 'Millions of USD';
  run; quit;

  ods tagsets.ExcelXP options(sheet_interval='none'
                              sheet_name='Annual Business Segments');

  proc print data=mylib.PharmaFinancial noobs label split='*';
    where segment eq 2;  * Annual Business Segments;
    by category;
    pageby category;     * Force a new title for each value of Category;
    id source / style(header)=header_id;
    var val2004-val2002 / style(data)=data_currency;
    sum val2002-val2004 / style(total)=header_currency  style(grandtotal)=header_currency;
    label source = 'Millions of USD';
  run; quit;

  ods tagsets.ExcelXP options(sheet_interval='none'
                              sheet_name='Quarterly Business Segments');

  proc print data=mylib.PharmaFinancial noobs label split='*';
    where segment eq 3;  * Quarterly Business Segments;
    by category;
    pageby category;     * Force a new title for each value of Category;
    id source / style(header)=header_id;
    var val2004-val2002 / style(data)=data_comma;
    sum val2002-val2004 / style(total)=header_comma  style(grandtotal)=header_comma;
    label source = 'Millions of USD';
  run; quit;

ods tagsets.ExcelXP close;