*  Directory for SAS code, data and output - remember trailing slash;

%let SAMPDIR=C:\HOW\DelGobbo\;

*  Library containing the sample data;

libname sample "&SAMPDIR" access=read;

*  Library to store styles and tagsets;

libname mylib "&SAMPDIR";

*  Set the ODS search path for styles and tagsets;

ods path mylib.tmplmst(update)
         sashelp.tmplmst(read);

*  Include recent version of the ExcelXP ODS tagset;

%include "&SAMPDIR.ExcelXP.sas";

*  Create some formats for our data;

proc format;
  value segment 1 = 'Annual Geographic Segments'
                2 = 'Annual Business Segments'
                3 = 'Quarterly Business Segments';

  value category 1 = 'External Revenue'
                 2 = 'Total Revenue'
                 3 = 'Long-Lived Assets'
                 4 = 'Depreciation'
                 5 = 'Operating Income/Loss';

  value $source 'US' = 'United States'
                'JP' = 'Japan'
                'EU' = 'Europe, Middle East and Africa'
                'OT' = 'Other'
                'PH' = 'Pharmaceutical Division'
                'AO' = 'All Other';
run;  quit;

*  Create a custom style based on the stock "sansPrinter" style;

proc template;

    define style styles.XLsansPrinter;
      parent = styles.sansPrinter;

      /* Controls the appearance of the ID "header" cell */

      style header_id from header /
        font_weight = light;

      /* Assign an Excel format - used with "data" cells */

      style data_comma_1 from data /
        tagattr = 'format:#,###.0';

      /* Assign an Excel format - used with "total" and "grand total" cells */

      style header_comma_1 from header /
        tagattr = 'format:#,###.0';

    end;
run; quit;